Struct teller_core::teller::Teller

source ·
pub struct Teller { /* private fields */ }

Implementations

source

impl Teller

source

pub async fn from_config(config: &Config) -> Result<Self>

Build from config

Errors

This function will return an error if loading fails

source

pub async fn from_yaml(file: &Path) -> Result<Self>

Build from YAML

Errors

This function will return an error if loading fails

source

pub async fn collect(&self) -> ProviderResult<Vec<KV>>

Collects kvs from all provider maps in the current configuration

Errors

This function will return an error if IO fails

source

pub async fn put( &self, kvs: &[KV], map_id: &str, providers: &[String] ) -> Result<()>

Put a list of KVs into a list of providers, on a specified path

Errors

This function will return an error if put fails

source

pub async fn delete( &self, keys: &[String], map_id: &str, providers: &[String] ) -> Result<()>

Delete a list of keys or a complete path for every provider in the list

Errors

This function will return an error if delete fails

source

pub fn get_pathmap_on_provider( &self, map_id: &str, provider_name: &String ) -> Result<(&Box<dyn Provider + Send + Sync>, &PathMap)>

Get a provider and pathmap from configuration and registry

Errors

This function will return an error if operation fails

source

pub async fn run<'a>(&self, cmd: &[&str], opts: &Opts<'a>) -> Result<Output>

Run an external command with provider based environment variables

Errors

This function will return an error if command fails

source

pub async fn redact<R: BufRead, W: Write>( &self, reader: R, writer: W ) -> Result<()>

Redact streams

Errors

This function will return an error if Is or collecting keys fails

source

pub async fn template(&self, template: &str) -> Result<String>

Populate a custom template with KVs

Errors

This function will return an error if template rendering fails

source

pub async fn export<'a>(&self, format: &Format) -> Result<String>

Export KV data

Errors

This function will return an error if export fails

source

pub fn scan(&self, root: &str, kvs: &[KV], opts: &Opts) -> Result<Vec<Match>>

Scan a folder recursively for secrets or values

Errors

This function will return an error if IO fails

source

pub async fn copy( &self, from_provider: &str, from_map_id: &str, to_provider: &str, to_map_id: &str, replace: bool ) -> Result<()>

Copy from provider to target provider. Note: replace will first delete data at target, then copy.

Errors

This function will return an error if copy fails